@@ -1,6 +1,7 @@
 from typing import Type
 from functools import wraps
 from time import time
+from logging import info
 
 def timing(f):
     # Decorator simples para medir tempo de excecucao de funcao
@@ -9,7 +10,7 @@ def timing(f):
         ts = time()
         result = f(*args, **kw)
         te = time()
-        print(f'Funcao {f.__name__} demoro {te-ts:2.4f} segundos')
+        info(f'Funcao {f.__name__} demoro {te-ts:2.4f} segundos')
         return result
     return wrap
 
